@@ -36,11 +36,13 @@ if [[ ! "$tmpdir" || ! -d "$tmpdir" ]]; then
   exit 1
 fi
 
-c="${cores:-4}"
-
-query_file=`realpath $query_file`
-accessory_dir=`realpath $accessory_dir`
-out_dir=`realpath $out_dir`
+export query_file=`realpath $query_file`
+export accessory_dir=`realpath $accessory_dir`
+export out_dir=`realpath $out_dir`
+export c="${cores:-4}"
+export data_type
+export tmpdir
+export upptmpdir
 
 # check whether output directory exist
 if [ ! -d "$out_dir" ]; then
@@ -55,7 +57,7 @@ echo "aligning the sequences..."
 
 # split query sequences into multiple files (/tmp directory)
 N=$(grep ">" ${query_file} | wc -l)
-awk -v size=1000000 -v pre=${upptmpdir}/seq -v pad="${#N}" '
+awk -v size=4000000 -v pre=${upptmpdir}/seq -v pad="${#N}" '
    /^>/ { n++; if (n % size == 1) { close(fname); fname = sprintf("%s.%0" pad "d", pre, n) } }
       { print >> fname }
 ' ${query_file}
@@ -89,29 +91,25 @@ awk -v size=5000 -v pre=${tmpdir}/split_seq/seq -v pad="${#N}" '
 
 function dist_place(){
   local seq_id=$1
+  local c=$2
+  local accessory_dir=$3
+  local data_type=$4
+  local tmpdir=$5
   depp_distance.py query_seq_file=$1 backbone_seq_file=${accessory_dir}/${data_type}_a.fasta outdir=../dist/$1 model_path=${accessory_dir}/${data_type}.ckpt replicate_seq=True recon_model_path=${accessory_dir}/${data_type}.recon.ckpt > /dev/null 2>&1
   jplace_suffix="${seq_id##*.}"
   apples_core=`python -c "print(min($c,4))"`
-  run_apples.py -d ${i}/depp.csv -t ${accessory_dir}/wol.nwk -o ${tmpdir}/${data_type}_${jplace_suffix}.jplace -f 0 -b 5 -T $apples_core > /dev/null 2>&1
+  run_apples.py -d ../dist/$1/depp.csv -t ${accessory_dir}/wol.nwk -o ${tmpdir}/${data_type}_${jplace_suffix}.jplace -f 0 -b 5 -T $apples_core > /dev/null 2>&1
+  rm ../dist/$1/depp.csv
+  rm ../dist/$1/*.pt
 }
+export -f dist_place
 
 echo "calculating distance matrix..."
 pushd ${tmpdir}/split_seq/ > /dev/null 2>&1
 depp_p=`python -c "print(max($c//4,1))"`
-#ls -1 seq* | xargs -n1 -P$depp_p -I% depp_distance.py query_seq_file="%" backbone_seq_file=${accessory_dir}/${data_type}_a.fasta outdir=../dist/"%" model_path=${accessory_dir}/${data_type}.ckpt replicate_seq=True recon_model_path=${accessory_dir}/${data_type}.recon.ckpt > /dev/null 2>&1
-ls -1 seq* | xargs -n1 -P$depp_p -I% dist_place "%"
+ls -1 seq* | xargs -n1 -P$depp_p -I% bash -c 'dist_place "%" "${c}" "${accessory_dir}" "${data_type}" "${tmpdir}"'
 popd > /dev/null 2>&1
 
-## do placement
-#echo "placing queries..."
-#cnt=0
-#for i in ${tmpdir}/dist/*;
-#do
-#  run_apples.py -d ${i}/depp.csv -t ${accessory_dir}/wol.nwk -o ${tmpdir}/${data_type}_${cnt}.jplace -f 0 -b 5 > /dev/null 2>&1
-#  rm ${i}/depp.csv
-#  cnt=$((cnt+1))
-#done
-
 
 cp ${tmpdir}/*.jplace ${out_dir}/
 #cp ${tmpdir}/placement.newick ${out_dir}/
@@ -124,5 +122,11 @@ function cleanup {
     rm -rf $tmpdir
     rm -rf $upptmpdir
     unset TMPDIR
+    unset query_file
+    unset out_dir
+    unset c
+    unset data_type
+    unset tmpdir
+    unset upptmpdir
 }
 trap cleanup EXIT
\ No newline at end of file
